@@ -216,7 +216,7 @@ class RmApiFS(fuse.Operations):
             elif isinstance(item, ModeFile):
                 entry.st_mode = (stat.S_IFREG | 0o644)
                 entry.st_size = await item.size()
-            stamp = int(item.mtime.timestamp() * 1e9)
+            stamp = max(int(item.mtime.timestamp() * 1e9), 0)
 
         entry.st_atime_ns = stamp
         entry.st_ctime_ns = stamp
@@ -500,6 +500,8 @@ def parse_args():
                         default=defaults['mode'], help="Type of files to mount")
     parser.add_argument('--write-config', action=WriteConfigAction, nargs=0,
                         help="Write a default configurations file")
+    parser.add_argument('--allow-other', dest='allow_other', action='store_const', const=True,
+                        default=False, help="Enable the allow_other FUSE flag")
     parser.add_argument('--version', action='version', version=VERSION)
     return parser.parse_args()
 
@@ -517,15 +519,18 @@ def main():
     fs = RmApiFS(options.mode)
     fuse_options = set(fuse.default_options)
     fuse_options.add('fsname=rmfuse')
+    if options.allow_other:
+        fuse_options.add('allow_other')
+
     # On Macs, don't allow metadata files
     if platform.system() == 'Darwin':
         fuse_options.add('noappledouble')
     # From llfuse; causes problems with fuse3
     fuse_options.discard('nonempty')
     if options.verbose == 1:
-        logging.basicConfig(level=logging.DEBUG)
-    elif options.verbose > 1:
         logging.basicConfig(level=logging.INFO)
+    elif options.verbose > 1:
+        logging.basicConfig(level=logging.DEBUG)
         # Fuse debug is really verbose, so stick that here.
         fuse_options.add('debug')
 
@@ -542,14 +547,14 @@ def main():
     # Trigger getting the client, to prompt for one-time code, if needed
     get_client_s()
     fuse.init(fs, options.mountpoint, fuse_options)
-    log.debug(f'Mounting on {options.mountpoint}')
+    log.info(f'Mounting on {options.mountpoint}')
     try:
         if is_pyfuse3:
             trio.run(fuse.main)
         else:
             fuse.main(workers=1)
     except KeyboardInterrupt:
-        log.debug('Exiting due to KeyboardInterrupt')
+        log.info('Exiting due to KeyboardInterrupt')
     except Exception:
         return 1
     finally:
